@@ -47,10 +47,10 @@ class WordToPdf(QtWidgets.QWidget,Ui_Form, demo.TableObject):
         self.warningSignal.connect(self.showmsg)
         self.reloadSignal.connect(self.ReloadBtn)
         self.ProBarSignal.connect(self.ProcessBarFun)
-        self.FunctionName = "这是移动文件到层级文件夹"
+        self.FunctionName = "将word文件转化为pdf文件"
         self.describetion = '''
 =================================================
-这是移动文件到层级文件夹
+这是将word文件转化为pdf文件的功能
 =================================================
     '''
 
